@@ -1,6 +1,6 @@
 package Email::Abstract::Courriel;
-BEGIN {
-  $Email::Abstract::Courriel::VERSION = '0.15';
+{
+  $Email::Abstract::Courriel::VERSION = '0.29';
 }
 
 use strict;
@@ -19,7 +19,7 @@ sub construct {
 
 sub get_header {
     my ( $class, $obj, $header ) = @_;
-    my @values = $obj->headers()->get($header);
+    my @values = map { $_->value() } $obj->headers()->get($header);
     return wantarray ? @values : $values[0];
 }
 
@@ -58,7 +58,7 @@ Email::Abstract::Courriel - Email::Abstract wrapper for Courriel
 
 =head1 VERSION
 
-version 0.15
+version 0.29
 
 =head1 DESCRIPTION
 
@@ -75,7 +75,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2012 by Dave Rolsky.
 
 This is free software, licensed under:
 
